==> scala-k8s-objects_sjs1_2.13-0.15.1-sources.jar: io/k8s/api/core/v1/NodeAffinity.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** Node affinity is a group of node affinity scheduling rules. */
final case class NodeAffinity(
  preferredDuringSchedulingIgnoredDuringExecution : Option[Seq[io.k8s.api.core.v1.PreferredSchedulingTerm]] = None,
  requiredDuringSchedulingIgnoredDuringExecution : Option[io.k8s.api.core.v1.NodeSelector] = None
) {

  /** Returns a new data with preferredDuringSchedulingIgnoredDuringExecution set to new value */
  def withPreferredDuringSchedulingIgnoredDuringExecution(value: Seq[io.k8s.api.core.v1.PreferredSchedulingTerm]) : NodeAffinity = copy(preferredDuringSchedulingIgnoredDuringExecution = Some(value))
  /** Appends new values to preferredDuringSchedulingIgnoredDuringExecution */
  def addPreferredDuringSchedulingIgnoredDuringExecution(newValues: io.k8s.api.core.v1.PreferredSchedulingTerm*) : NodeAffinity = copy(preferredDuringSchedulingIgnoredDuringExecution = Some(preferredDuringSchedulingIgnoredDuringExecution.fold(newValues)(_ ++ newValues)))
  /** if preferredDuringSchedulingIgnoredDuringExecution has a value, transforms to the result of function*/
  def mapPreferredDuringSchedulingIgnoredDuringExecution(f: Seq[io.k8s.api.core.v1.PreferredSchedulingTerm] => Seq[io.k8s.api.core.v1.PreferredSchedulingTerm]) : NodeAffinity = copy(preferredDuringSchedulingIgnoredDuringExecution = preferredDuringSchedulingIgnoredDuringExecution.map(f))

  /** Returns a new data with requiredDuringSchedulingIgnoredDuringExecution set to new value */
  def withRequiredDuringSchedulingIgnoredDuringExecution(value: io.k8s.api.core.v1.NodeSelector) : NodeAffinity = copy(requiredDuringSchedulingIgnoredDuringExecution = Some(value))
  /** if requiredDuringSchedulingIgnoredDuringExecution has a value, transforms to the result of function*/
  def mapRequiredDuringSchedulingIgnoredDuringExecution(f: io.k8s.api.core.v1.NodeSelector => io.k8s.api.core.v1.NodeSelector) : NodeAffinity = copy(requiredDuringSchedulingIgnoredDuringExecution = requiredDuringSchedulingIgnoredDuringExecution.map(f))
}

object NodeAffinity {

    implicit val encoder : Encoder[io.k8s.api.core.v1.NodeAffinity] = new Encoder[io.k8s.api.core.v1.NodeAffinity] {
        def apply[T : Builder](o: io.k8s.api.core.v1.NodeAffinity) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("preferredDuringSchedulingIgnoredDuringExecution", o.preferredDuringSchedulingIgnoredDuringExecution)
            .write("requiredDuringSchedulingIgnoredDuringExecution", o.requiredDuringSchedulingIgnoredDuringExecution)
            .build
        }
    }

    implicit val decoder: Decoder[NodeAffinity] = new Decoder[NodeAffinity] {
      def apply[T : Reader](t: T): Either[String, NodeAffinity] = for {
          obj <- ObjectReader(t)
          preferredDuringSchedulingIgnoredDuringExecution <- obj.readOpt[Seq[io.k8s.api.core.v1.PreferredSchedulingTerm]]("preferredDuringSchedulingIgnoredDuringExecution")
          requiredDuringSchedulingIgnoredDuringExecution <- obj.readOpt[io.k8s.api.core.v1.NodeSelector]("requiredDuringSchedulingIgnoredDuringExecution")
      } yield NodeAffinity (
          preferredDuringSchedulingIgnoredDuringExecution = preferredDuringSchedulingIgnoredDuringExecution,
          requiredDuringSchedulingIgnoredDuringExecution = requiredDuringSchedulingIgnoredDuringExecution
        )
    }
}

==> scala-k8s-objects_sjs1_3-0.3.0-sources.jar: io/k8s/api/core/v1/NodeAffinity.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** Node affinity is a group of node affinity scheduling rules. */
final case class NodeAffinity(
  preferredDuringSchedulingIgnoredDuringExecution : Option[Seq[io.k8s.api.core.v1.PreferredSchedulingTerm]] = None,
  requiredDuringSchedulingIgnoredDuringExecution : Option[io.k8s.api.core.v1.NodeSelector] = None
) {

  /** Returns a new data with preferredDuringSchedulingIgnoredDuringExecution set to new value */
  def withPreferredDuringSchedulingIgnoredDuringExecution(value: Seq[io.k8s.api.core.v1.PreferredSchedulingTerm]) : NodeAffinity = copy(preferredDuringSchedulingIgnoredDuringExecution = Some(value))
  /** Appends new values to preferredDuringSchedulingIgnoredDuringExecution */
  def addPreferredDuringSchedulingIgnoredDuringExecution(newValues: io.k8s.api.core.v1.PreferredSchedulingTerm*) : NodeAffinity = copy(preferredDuringSchedulingIgnoredDuringExecution = Some(preferredDuringSchedulingIgnoredDuringExecution.fold(newValues)(_ ++ newValues)))
  /** if preferredDuringSchedulingIgnoredDuringExecution has a value, transforms to the result of function*/
  def mapPreferredDuringSchedulingIgnoredDuringExecution(f: Seq[io.k8s.api.core.v1.PreferredSchedulingTerm] => Seq[io.k8s.api.core.v1.PreferredSchedulingTerm]) : NodeAffinity = copy(preferredDuringSchedulingIgnoredDuringExecution = preferredDuringSchedulingIgnoredDuringExecution.map(f))

  /** Returns a new data with requiredDuringSchedulingIgnoredDuringExecution set to new value */
  def withRequiredDuringSchedulingIgnoredDuringExecution(value: io.k8s.api.core.v1.NodeSelector) : NodeAffinity = copy(requiredDuringSchedulingIgnoredDuringExecution = Some(value))
  /** if requiredDuringSchedulingIgnoredDuringExecution has a value, transforms to the result of function*/
  def mapRequiredDuringSchedulingIgnoredDuringExecution(f: io.k8s.api.core.v1.NodeSelector => io.k8s.api.core.v1.NodeSelector) : NodeAffinity = copy(requiredDuringSchedulingIgnoredDuringExecution = requiredDuringSchedulingIgnoredDuringExecution.map(f))
}

object NodeAffinity {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.core.v1.NodeAffinity, T] = new Encoder[io.k8s.api.core.v1.NodeAffinity, T] {
        def apply(o: io.k8s.api.core.v1.NodeAffinity) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("preferredDuringSchedulingIgnoredDuringExecution", o.preferredDuringSchedulingIgnoredDuringExecution)
            .write("requiredDuringSchedulingIgnoredDuringExecution", o.requiredDuringSchedulingIgnoredDuringExecution)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, NodeAffinity] = new Decoder[T, NodeAffinity] {
      def apply(t: T): Either[String, NodeAffinity] = for {
          obj <- ObjectReader(t)
          preferredDuringSchedulingIgnoredDuringExecution <- obj.readOpt[Seq[io.k8s.api.core.v1.PreferredSchedulingTerm]]("preferredDuringSchedulingIgnoredDuringExecution")
          requiredDuringSchedulingIgnoredDuringExecution <- obj.readOpt[io.k8s.api.core.v1.NodeSelector]("requiredDuringSchedulingIgnoredDuringExecution")
      } yield NodeAffinity (
          preferredDuringSchedulingIgnoredDuringExecution = preferredDuringSchedulingIgnoredDuringExecution,
          requiredDuringSchedulingIgnoredDuringExecution = requiredDuringSchedulingIgnoredDuringExecution
        )
    }
}
